Active Alarms Alarm History
Started Ended

| {$ 'Severity' | translate $} | {$ 'Started' | translate $} | {$ 'Ended' | translate $} | {$ 'Name' | translate $} | {$ 'Resource Type' | translate $} | {$ 'Resource ID' | translate $} | {$ 'Type' | translate $} | {$ 'RCA' | translate $} |
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| {$alarm.vitrage_aggregated_severity | lowercase$} | {$alarm.start_timestamp | vitrageDate:alarmList.dateFormat:alarmList.timezone $} | {$alarm.end_timestamp | vitrageDate:alarmList.dateFormat:alarmList.timezone $} | {$alarm.name$} | {$alarm.vitrage_resource_type$} | {$alarm.vitrage_resource_id$} | {$alarm.vitrage_type$} |  |